@@ -8,12 +8,12 @@ from typing import Dict
 from typing import List
 from typing import Sequence
 from typing import Tuple
+
 from gitignore_parser import parse_gitignore
 
 from potodo import __version__
 from potodo.arguments_handling import check_args
 from potodo.github import get_issue_reservations
-
 from potodo.json import json_dateconv
 from potodo.logging import setup_logging
 from potodo.po_file import get_po_stats_from_repo_or_cache
@@ -81,36 +81,19 @@ def non_interactive_output(
 ) -> None:
     dir_stats: List[Any] = []
     # Initialize the arguments
-    cache_args = {
-        "path": path,
-        "exclude": exclude,
-        "above": above,
-        "below": below,
-        "only_fuzzy": only_fuzzy,
-        "offline": offline,
-        "hide_reserved": hide_reserved,
-        "counts": counts,
-        "json_format": json_format,
-        "exclude_fuzzy": exclude_fuzzy,
-        "exclude_reserved": exclude_reserved,
-        "only_reserved": only_reserved,
-        "show_reservation_dates": show_reservation_dates,
-        "no_cache": no_cache,
-        "is_interactive": is_interactive,
-    }
     issue_reservations = get_issue_reservations(offline, hide_reserved, path)
 
     total_translated: int = 0
     total_entries: int = 0
     po_files_and_dirs = get_po_stats_from_repo_or_cache(
-        path, exclude, cache_args, ignore_matches, no_cache
+        path, exclude, ignore_matches, no_cache
     )
     for directory_name, po_files in sorted(po_files_and_dirs.items()):
         # For each directory and files in this directory
         buffer: List[Any] = []
         folder_stats: Dict[str, int] = {"translated": 0, "total": 0}
         printed_list: List[bool] = []
-    
+
         for po_file in sorted(po_files):
             # For each file in those files from that directory
             if not only_fuzzy or po_file.fuzzy_entries:
@@ -131,17 +114,15 @@ def non_interactive_output(
                     show_reservation_dates,
                     matching_files,
                 )
-    
+
         # Once all files have been processed, print the dir and the files
         # or store them into a dict to print them once all directories have
         # been processed.
         if json_format:
-            add_dir_stats(
-                directory_name, buffer, folder_stats, printed_list, dir_stats
-            )
+            add_dir_stats(directory_name, buffer, folder_stats, printed_list, dir_stats)
         else:
             print_dir_stats(directory_name, buffer, folder_stats, printed_list)
-    
+
         total_translated += folder_stats["translated"]
         total_entries += folder_stats["total"]
 
@@ -156,8 +137,9 @@ def non_interactive_output(
             )
         )
     else:
-        total_completion = 100 * total_translated / total_entries
-        print(f"\n\n# TOTAL ({total_completion:.2f}% done)\n")
+        if total_entries != 0:
+            total_completion = 100 * total_translated / total_entries
+            print(f"\n\n# TOTAL ({total_completion:.2f}% done)\n")
 
 
 def exec_potodo(
@@ -206,6 +188,7 @@ def exec_potodo(
 
     if is_interactive:
         from potodo.interactive import interactive_output
+
         interactive_output(path, exclude, ignore_matches)
     else:
         non_interactive_output(
